@@ -7,6 +7,9 @@ import gobject
 import os, sys
 import tempfile
 
+#Let's try to use some Google cards
+import gsearch
+
 #Maemo-specific alarm functionality
 try:
 	import alarm
@@ -67,6 +70,9 @@ def parse_input(input):
 	elif exists_in_order(['answer','life','universe','everything'],input.split()) or exists_in_order(['meaning','life','universe','everything'],input.split()):
 		return life_the_universe_and_everything(), None
 
+	elif exists_in_order(['chuck', 'norris'], input.split()):
+		return chuck_norris(input), None
+
 	elif 'wake' in input:
 		return new_alarm(input)
 
@@ -75,6 +81,10 @@ def parse_input(input):
 		
 	elif exists_in_order(['my','location'],input.split()) or exists_in_order(['where', 'i'],input.split()):
 		return where_am_i(input)
+
+	#Rather last-ditch: if we can't parse, ask Google
+	elif input.startswith("what") or input.startswith("who") or input.startswith("where") or input.startswith("how") or input.startswith("where"):
+		return search_google(input)
 		
 	elif input in ("quit ", "go away "):
 		gobject.timeout_add(3000,sys.exit,0)
@@ -470,6 +480,16 @@ def new_alarm(input):
 
 	return "Okay, I set your alarm for "+time.strftime("%I:%M %P"), None
 
+def search_google(input):
+	a, b, loc = gsearch.search(input)
+	if a and b:
+		return a + ' is '+b+'.', None
+	elif loc:
+		return 'Let me search for '+food, "gobject.timeout_add(500, os.system, 'python /opt/modrana/modrana.py --address-search "+food+"')"
+
+def chuck_norris(input):
+	return sent.chuck_norris[random.randint(0,len(sent.chuck_norris))]
+
 ###################################################
 	
 if __name__=='__main__':
